Module: Hcp::Named

Included in:
Customer, Employee
Defined in:
lib/hcp/concerns/named.rb

Overview

Extends a record Housecall Pro holds a person's names for.

Instance Method Summary collapse

Instance Method Details

#nameString

Returns what they are called, by whichever of their names Housecall Pro holds.

Returns:

  • (String)

    what they are called, by whichever of their names Housecall Pro holds.



5
# File 'lib/hcp/concerns/named.rb', line 5

def name = [ @node['first_name'], @node['last_name'] ].compact_blank.join ' '