Module: Hcp::Scheduled

Included in:
Estimate, Job
Defined in:
lib/hcp/concerns/scheduled.rb

Overview

Extends a record Housecall Pro books work for and stamps as the work happens.

Instance Method Summary collapse

Instance Method Details

#completed_atTime?

Returns when the work was finished.

Returns:

  • (Time, nil)

    when the work was finished.



14
# File 'lib/hcp/concerns/scheduled.rb', line 14

def completed_at = time 'work_timestamps', 'completed_at'

#on_my_way_atTime?

Returns when the pro said they were on their way.

Returns:

  • (Time, nil)

    when the pro said they were on their way.



8
# File 'lib/hcp/concerns/scheduled.rb', line 8

def on_my_way_at = time 'work_timestamps', 'on_my_way_at'

#scheduleSchedule?

Returns when the work is booked for.

Returns:

  • (Schedule, nil)

    when the work is booked for.



5
# File 'lib/hcp/concerns/scheduled.rb', line 5

def schedule = record Schedule, 'schedule'

#started_atTime?

Returns when the work started.

Returns:

  • (Time, nil)

    when the work started.



11
# File 'lib/hcp/concerns/scheduled.rb', line 11

def started_at = time 'work_timestamps', 'started_at'