Module: Hcp
- Defined in:
- lib/hcp/version.rb,
lib/hcp/resource.rb,
lib/hcp/key.rb,
lib/hcp/lead.rb,
lib/hcp/error.rb,
lib/hcp/event.rb,
lib/hcp/answer.rb,
lib/hcp/filter.rb,
lib/hcp/request.rb,
lib/hcp/relation.rb,
lib/hcp/lead/pipeline.rb,
lib/hcp/resources/job.rb,
lib/hcp/concerns/keyed.rb,
lib/hcp/concerns/named.rb,
lib/hcp/resources/note.rb,
lib/hcp/errors/not_found.rb,
lib/hcp/concerns/statused.rb,
lib/hcp/resources/address.rb,
lib/hcp/concerns/chainable.rb,
lib/hcp/concerns/queryable.rb,
lib/hcp/concerns/scheduled.rb,
lib/hcp/resources/customer.rb,
lib/hcp/resources/employee.rb,
lib/hcp/resources/estimate.rb,
lib/hcp/resources/schedule.rb,
lib/hcp/resources/line_item.rb,
lib/hcp/concerns/timestamped.rb,
lib/hcp/resources/job/invoice.rb,
lib/hcp/errors/too_many_requests.rb,
lib/hcp/resources/estimate/option.rb,
lib/hcp/resources/job/appointment.rb
Overview
Ruby client for the Housecall Pro API.
Defined Under Namespace
Modules: Chainable, Keyed, Named, Queryable, Scheduled, Statused, Timestamped Classes: Address, Answer, Customer, Employee, Estimate, Event, Filter, Job, Lead, LineItem, Note, Relation, Request, Resource, Schedule, TooManyRequests
Constant Summary collapse
- Error =
Raised where Housecall Pro would not answer.
Class.new StandardError
- VERSION =
Current version of the gem.
'1.3.0'- NotFound =
Raised where Housecall Pro has no record under the ID it was asked for.
Class.new Error
Class Attribute Summary collapse
-
.key ⇒ String?
The key this module was given, or the one the environment carries.
Class Attribute Details
.key ⇒ String?
Returns the key this module was given, or the one the environment carries.
7 |
# File 'lib/hcp/key.rb', line 7 def key = @key || ENV['HCP_KEY'] |