Module: Hcp::Named
Overview
Extends a record Housecall Pro holds a person's names for.
Instance Method Summary collapse
-
#name ⇒ String
What they are called, by whichever of their names Housecall Pro holds.
Instance Method Details
#name ⇒ String
Returns what they are called, by whichever of their names Housecall Pro holds.
5 |
# File 'lib/hcp/concerns/named.rb', line 5 def name = [ @node['first_name'], @node['last_name'] ].compact_blank.join ' ' |