Module: Hcp::Scheduled
Overview
Extends a record Housecall Pro books work for and stamps as the work happens.
Instance Method Summary collapse
-
#completed_at ⇒ Time?
When the work was finished.
-
#on_my_way_at ⇒ Time?
When the pro said they were on their way.
-
#schedule ⇒ Schedule?
When the work is booked for.
-
#started_at ⇒ Time?
When the work started.
Instance Method Details
#completed_at ⇒ Time?
Returns when the work was finished.
14 |
# File 'lib/hcp/concerns/scheduled.rb', line 14 def completed_at = time 'work_timestamps', 'completed_at' |
#on_my_way_at ⇒ Time?
Returns when the pro said they were on their way.
8 |
# File 'lib/hcp/concerns/scheduled.rb', line 8 def on_my_way_at = time 'work_timestamps', 'on_my_way_at' |
#schedule ⇒ Schedule?
Returns when the work is booked for.
5 |
# File 'lib/hcp/concerns/scheduled.rb', line 5 def schedule = record Schedule, 'schedule' |
#started_at ⇒ Time?
Returns when the work started.
11 |
# File 'lib/hcp/concerns/scheduled.rb', line 11 def started_at = time 'work_timestamps', 'started_at' |